@@ -132,6 +132,7 @@ static NSString *test[20] =
   NSScrollView *scrollView;
   int i;
   NSString *string;
+  NSCell *cell;
 
   keysArray = [[NSMutableArray alloc] initWithObjects: keys
 				      count:20];
@@ -168,10 +169,23 @@ static NSString *test[20] =
   //  [tableView setAutoresizesAllColumnsToFit: YES];
   [tableView setAllowsMultipleSelection: YES];
 
-
+  /* column with selectable but not editable cell */  
+  string = @"Selectable";
+  tb = AUTORELEASE ([[NSTableColumn alloc] initWithIdentifier: string]);
+  [tb setEditable: YES];
+  [tb setMinWidth: 50];
+  [tb setMaxWidth: 400];
+  [[tb headerCell] setStringValue: string];
+ 
+  cell = [tb dataCell];
+  [cell setSelectable: YES];
+  [cell setEditable: YES];
+  [tb setDataCell: cell];
+  NSLog(@"data cell %@", cell);
+  [tableView addTableColumn: tb];
 
   /* Now add some more columns */
-  for (i = 0; i < 5; i++)
+  for (i = 1; i < 5; i++)
     {
       string = [NSString stringWithFormat: @"Column %d", i];
       tb = AUTORELEASE ([[NSTableColumn alloc] initWithIdentifier: string]);
@@ -341,7 +355,7 @@ static NSString *test[20] =
 
 - (NSDragOperation) tableView: (NSTableView *) tv
 		 validateDrop: (id <NSDraggingInfo>) info
-		  proposedRow: (int) row
+		  proposedRow: (NSInteger) row
 	proposedDropOperation: (NSTableViewDropOperation) operation
 
 {
@@ -355,7 +369,7 @@ static NSString *test[20] =
 
 - (BOOL) tableView: (NSTableView *)tv
 	acceptDrop: (id <NSDraggingInfo>) info
-	       row: (int) row
+	       row: (NSInteger) row
      dropOperation: (NSTableViewDropOperation) operation
 {
   NSDragOperation dragOperation;
@@ -367,10 +381,10 @@ static NSString *test[20] =
     dragOperation = NSDragOperationNone;
 
   {
-    int i, j;
+    NSInteger i, j;
     NSArray *pl = [[info draggingPasteboard] propertyListForType:
 					       NSTableViewTestPboardType];
-    int count = [pl count];
+    NSUInteger count = [pl count];
 
     for ( i = count - 1; i >= 0; i-- )
       {
