@@ -1,6 +1,6 @@
 /* testList.h: List of Implemented Tests 
 
-   Copyright (C) 1999 Free Software Foundation, Inc.
+   Copyright (C) 1999-2010 Free Software Foundation, Inc.
 
    Author:  Nicola Pero <n.pero@mi.flashnet.it>
    Date: 1999
@@ -54,7 +54,7 @@
 // 
 
 // Number of tests in the list
-#define TEST_NUMBER 19
+#define TEST_NUMBER 23
 struct 
 {
   NSString *menuName;      // Name shown on the menu
@@ -79,9 +79,14 @@ testList[TEST_NUMBER] =
   {@"NSSplitView", @"NSSplitView-test"},
   {@"NSTextView", @"NSTextView-test"},
   {@"NSTableView", @"NSTableView-test"},
+  {@"NSProgressIndicator", @"NSProgressIndicator-test"},
   {@"NSWindowStyleMask", @"NSWindowStyleMask-test"},
   {@"StringDrawing", @"StringDrawing-test"},
-  {@"NSOutlineView", @"NSOutlineView-test"}
+  {@"NSOutlineView", @"NSOutlineView-test"},
+  {@"Pixel Exact Drawing", @"PixelExactDrawing-test"},
+  {@"Image Selection", @"ImageSelection-test"},
+  {@"Image Test", @"Image-test"},
+  {@"Transparency Test", @"Transparency-test"}
 };
 
 struct 
